@@ -1,6 +1,6 @@
-version="0.9.21.0.009"
+version="0.9.23.0.001"
 
-date = '2021-10-14'
+date = '2023-2-28'
 
 dpi = 64
 # coding:utf-8
@@ -1274,7 +1274,7 @@ class AppForm(QMainWindow):
         print('get Multiple Data Files  called \n')
         DataFilesInput, filetype = QFileDialog.getOpenFileNames(self, u'Choose Data File',
                                                                 '~/',
-                                                                'Excel Files (*.xlsx);;Excel 2003 Files (*.xls);;CSV Files (*.csv)')  # 设置文件扩展名过滤,注意用双分号间隔
+                                                                'CSV Files (*.csv);;Excel Files (*.xlsx);;Excel 2003 Files (*.xls)')  # 设置文件扩展名过滤,注意用双分号间隔
         # print(DataFileInput,filetype)
 
         DataFramesList = []
@@ -1297,7 +1297,7 @@ class AppForm(QMainWindow):
 
         DataFileInput, filetype = QFileDialog.getOpenFileName(self, _translate('MainWindow', u'Choose Data File'),
                                                               '~/',
-                                                              'Excel Files (*.xlsx);;Excel 2003 Files (*.xls);;CSV Files (*.csv)')  # 设置文件扩展名过滤,注意用双分号间隔
+                                                              'CSV Files (*.csv);;Excel Files (*.xlsx);;Excel 2003 Files (*.xls)')  # 设置文件扩展名过滤,注意用双分号间隔
         print(DataFileInput)
 
         raw_input_data = pd.DataFrame()
@@ -2404,4 +2404,4 @@ class Lsq():
 
 LocationOfMySelf = os.path.dirname(__file__)
 
-# print(LocationOfMySelf,'Custom Bass Classes')
\ No newline at end of file
+# print(LocationOfMySelf,'Custom Bass Classes')
